@@ -30,7 +30,12 @@ sub file {
 $App::perlbrew::PERLBREW_ROOT = tempdir( CLEANUP => 1 );
 $App::perlbrew::PERLBREW_HOME = tempdir( CLEANUP => 1 );
 $ENV{PERLBREW_ROOT} = $App::perlbrew::PERLBREW_ROOT;
+
 delete $ENV{PERLBREW_LIB};
+delete $ENV{PERLBREW_PERL};
+delete $ENV{PERLBREW_PATH};
+delete $ENV{PERLBREW_MANPATH};
+delete $ENV{PERL_LOCAL_LIB_ROOT};
 
 my $root = App::Perlbrew::Path::Root->new ($ENV{PERLBREW_ROOT});
 $root->perls->mkpath;
@@ -72,6 +77,24 @@ sub mock_perlbrew_install {
     App::perlbrew->new(install => $name, @args)->run();
 }
 
+sub mock_perlbrew_off {
+    mock_perlbrew_use("");
+}
+
+sub mock_perlbrew_use {
+    my ($name) = @_;
+
+    my %env = App::perlbrew->new()->perlbrew_env($name);
+
+    for my $k (qw< PERLBREW_PERL PERLBREW_LIB PERLBREW_PATH PERL5LIB >) {
+        if (defined $env{$k}) {
+            $ENV{$k} = $env{$k};
+        } else {
+            delete $ENV{$k}
+        }
+    }
+}
+
 sub mock_perlbrew_lib_create {
     my $name = shift;
     App::Perlbrew::Path->new($App::perlbrew::PERLBREW_HOME, "libs", $name)->mkpath;
